==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/content/equipment/toolbox/ToolboxDyeingRecipe.java <==
package com.zurrtum.create.content.equipment.toolbox;

import com.zurrtum.create.AllItemTags;
import com.zurrtum.create.AllRecipeSerializers;
import net.minecraft.class_1767;
import net.minecraft.class_1799;
import net.minecraft.class_1852;
import net.minecraft.class_1865;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_7225;
import net.minecraft.class_7710;
import net.minecraft.class_9326;
import net.minecraft.class_9694;

public class ToolboxDyeingRecipe extends class_1852 {

    public ToolboxDyeingRecipe(class_7710 category) {
        super(category);
    }

    @Override
    public boolean matches(class_9694 input, class_1937 level) {
        int toolboxes = 0;
        int dyes = 0;

        for (int i = 0; i < input.method_59983(); ++i) {
            class_1799 stack = input.method_59984(i);
            if (!stack.method_7960()) {
                if (class_2248.method_9503(stack.method_7909()) instanceof ToolboxBlock) {
                    ++toolboxes;
                } else {
                    if (!stack.method_31573(AllItemTags.DYES))
                        return false;
                    ++dyes;
                }

                if (dyes > 1 || toolboxes > 1) {
                    return false;
                }
            }
        }

        return toolboxes == 1 && dyes == 1;
    }

    @Override
    public class_1799 craft(class_9694 input, class_7225.class_7874 registries) {
        class_1799 toolbox = class_1799.field_8037;
        class_1767 color = class_1767.field_7957;

        for (int i = 0; i < input.method_59983(); ++i) {
            class_1799 stack = input.method_59984(i);
            if (!stack.method_7960()) {
                if (class_2248.method_9503(stack.method_7909()) instanceof ToolboxBlock) {
                    toolbox = stack;
                } else {
                    class_1767 color1 = AllItemTags.getDyeColor(stack);
                    if (color1 != null) {
                        color = color1;
                    }
                }
            }
        }

        class_1799 dyedToolbox = ToolboxBlock.getColorBlock(color).method_8389().method_7854();
        class_9326 componentChanges = toolbox.method_57380();
        if (!componentChanges.method_57848()) {
            dyedToolbox.method_57366(componentChanges);
        }

        return dyedToolbox;
    }

    @Override
    public class_1865<ToolboxDyeingRecipe> method_8119() {
        return AllRecipeSerializers.TOOLBOX_DYEING;
    }

}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/equipment/toolbox/ToolboxDyeingRecipe.java <==
package com.zurrtum.create.content.equipment.toolbox;

import com.zurrtum.create.AllItemTags;
import com.zurrtum.create.AllRecipeSerializers;
import net.minecraft.class_1767;
import net.minecraft.class_1799;
import net.minecraft.class_1852;
import net.minecraft.class_1865;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_7225;
import net.minecraft.class_7710;
import net.minecraft.class_9326;
import net.minecraft.class_9694;

public class ToolboxDyeingRecipe extends class_1852 {

    public ToolboxDyeingRecipe(class_7710 category) {
        super(category);
    }

    @Override
    public boolean matches(class_9694 input, class_1937 level) {
        int toolboxes = 0;
        int dyes = 0;

        for (int i = 0; i < input.method_59983(); ++i) {
            class_1799 stack = input.method_59984(i);
            if (!stack.method_7960()) {
                if (class_2248.method_9503(stack.method_7909()) instanceof ToolboxBlock) {
                    ++toolboxes;
                } else {
                    if (!stack.method_31573(AllItemTags.DYES))
                        return false;
                    ++dyes;
                }

                if (dyes > 1 || toolboxes > 1) {
                    return false;
                }
            }
        }

        return toolboxes == 1 && dyes == 1;
    }

    @Override
    public class_1799 assemble(class_9694 input, class_7225.class_7874 registries) {
        class_1799 toolbox = class_1799.field_8037;
        class_1767 color = class_1767.field_7957;

        for (int i = 0; i < input.method_59983(); ++i) {
            class_1799 stack = input.method_59984(i);
            if (!stack.method_7960()) {
                if (class_2248.method_9503(stack.method_7909()) instanceof ToolboxBlock) {
                    toolbox = stack;
                } else {
                    class_1767 color1 = AllItemTags.getDyeColor(stack);
                    if (color1 != null) {
                        color = color1;
                    }
                }
            }
        }

        class_1799 dyedToolbox = ToolboxBlock.getColorBlock(color).method_8389().method_7854();
        class_9326 componentChanges = toolbox.method_57380();
        if (!componentChanges.method_57848()) {
            dyedToolbox.method_57366(componentChanges);
        }

        return dyedToolbox;
    }

    @Override
    public class_1865<ToolboxDyeingRecipe> method_8119() {
        return AllRecipeSerializers.TOOLBOX_DYEING;
    }

}
